@@ -7,19 +7,21 @@
 ****************************************************************************/
 
 /*
- *  This program is free software; you can redistribute it and/or modify
+ *  Brasero is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Brasero is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Library General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, write to:
+ * 	The Free Software Foundation, Inc.,
+ * 	51 Franklin Street, Fifth Floor
+ * 	Boston, MA  02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -269,6 +271,11 @@ brasero_player_update_position (BraseroPlayer *player)
 	value = gtk_range_get_value (GTK_RANGE (player->priv->progress));
 	pos_string = brasero_utils_get_time_string (value, FALSE, FALSE);
 
+	/**
+	 * Translators: this is the position being played in the stream. The 
+	 * first %s is the position and the second %s is the whole length of
+	 * the stream. I chose to make that translatable in case some languages
+	 * don't allow the "/" */
 	result = g_strdup_printf (_("%s / %s"), pos_string, len_string);
 	g_free (len_string);
 	g_free (pos_string);
@@ -296,7 +303,7 @@ brasero_player_range_value_changed (GtkRange *range,
 static void
 brasero_player_set_length (BraseroPlayer *player)
 {
-	if (player->priv->progress)
+	if (player->priv->progress && player->priv->end - player->priv->start != 0)
 		gtk_range_set_range (GTK_RANGE (player->priv->progress),
 				     0.0,
 				     (gdouble) player->priv->end - player->priv->start);
@@ -804,7 +811,9 @@ brasero_player_image (BraseroPlayer *player)
 	BRASERO_GET_BASENAME_FOR_DISPLAY (path, name);
 	g_free (path);
 
-	string = g_strdup_printf (_("<span weight=\"bold\">Name:</span>\t %s"), name);
+	string = g_strdup_printf ("<span weight=\"bold\">%s</span>\t %s",
+				  _("Name:"),
+				  name);
 	g_free (name);
 
 	gtk_label_set_markup (GTK_LABEL (player->priv->header), string);
@@ -841,8 +850,7 @@ brasero_player_update_info_real (BraseroPlayer *player,
 
 	}
 	else if (title) {
-		header = g_markup_printf_escaped (_("<span weight=\"bold\">%s</span>\n"),
-						  title);
+		header = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>\n", title);
 		gtk_label_set_ellipsize (GTK_LABEL (player->priv->header),
 					 PANGO_ELLIPSIZE_END);
 	}
@@ -850,8 +858,7 @@ brasero_player_update_info_real (BraseroPlayer *player,
 		gchar *name;
 
 	    	BRASERO_GET_BASENAME_FOR_DISPLAY (player->priv->uri, name);
-		header = g_markup_printf_escaped (_("<span weight=\"bold\">%s</span>\n"),
-						  name);
+		header = g_markup_printf_escaped ("<span weight=\"bold\">%s</span>\n", name);
 		g_free (name);
 		gtk_label_set_ellipsize (GTK_LABEL (player->priv->header),
 					 PANGO_ELLIPSIZE_END);
