@@ -7,19 +7,21 @@
  ***************************************************************************/
 
 /*
- *  This program is free software; you can redistribute it and/or modify
+ *  Brasero is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Brasero is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Library General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, write to:
+ * 	The Free Software Foundation, Inc.,
+ * 	51 Franklin Street, Fifth Floor
+ * 	Boston, MA  02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,6 +32,8 @@
 #include <errno.h>
 #include <fcntl.h>
 #include <unistd.h>
+#include <sys/time.h>
+#include <sys/resource.h>
 
 #include <glib.h>
 #include <glib-object.h>
@@ -420,16 +424,20 @@ brasero_job_check_output_volume_space (BraseroJob *self,
 	GFile *file;
 	GFileInfo *info;
 	gchar *directory;
+	struct rlimit limit;
 	guint64 vol_size = 0;
 	gint64 output_size = 0;
 	BraseroJobPrivate *priv;
+	const gchar *filesystem;
 
 	/* now that the job has a known output we must check that the volume the
 	 * job is writing to has enough space for all output */
 
 	priv = BRASERO_JOB_PRIVATE (self);
 
-	/* get the size of the volume first */
+	/* get the size and filesystem type for the volume first.
+	 * NOTE: since any plugin must output anything LOCALLY, we can then use
+	 * all libc API. */
 	if (!priv->output)
 		return BRASERO_BURN_ERR;
 
@@ -441,7 +449,8 @@ brasero_job_check_output_volume_space (BraseroJob *self,
 		goto error;
 
 	info = g_file_query_filesystem_info (file,
-					     G_FILE_ATTRIBUTE_FILESYSTEM_FREE,
+					     G_FILE_ATTRIBUTE_FILESYSTEM_FREE ","
+					     G_FILE_ATTRIBUTE_FILESYSTEM_TYPE,
 					     NULL,
 					     error);
 	if (!info)
@@ -449,19 +458,53 @@ brasero_job_check_output_volume_space (BraseroJob *self,
 
 	g_object_unref (file);
 
+	brasero_job_get_session_output_size (BRASERO_JOB (self), NULL, &output_size);
+
+	/* Now check the filesystem type: the problem here is that some
+	 * filesystems have a maximum file size limit of 4 GiB and more than
+	 * often we need a temporary file size of 4 GiB or more. */
+	filesystem = g_file_info_get_attribute_string (info, G_FILE_ATTRIBUTE_FILESYSTEM_TYPE);
+	BRASERO_BURN_LOG ("%s filesystem detected", filesystem);
+
+	if (output_size >= 2147483648ULL
+	&&  filesystem
+	&& !strcmp (filesystem, "msdos")) {
+		g_set_error (error,
+			     BRASERO_BURN_ERROR,
+			     BRASERO_BURN_ERROR_DISK_SPACE,
+			     _("The filesystem you chose to store the temporary image on cannot hold files with a size over 2 GiB."));
+		return BRASERO_BURN_ERR;
+	}
+
 	vol_size = g_file_info_get_attribute_uint64 (info, G_FILE_ATTRIBUTE_FILESYSTEM_FREE);
 	g_object_unref (info);
 
 	/* get the size of the output this job is supposed to create */
-	brasero_job_get_session_output_size (BRASERO_JOB (self), NULL, &output_size);
-
 	BRASERO_BURN_LOG ("Volume size %lli, output size %lli", vol_size, output_size);
 
 	/* it's fine here to check size in bytes */
 	if (output_size > vol_size) {
-		/* FIXME: This string should mention that the location is on the
-		 * hard drive and not the medium itself to prevent any confusion
-		 * as seen in #533149 */
+		g_set_error (error,
+			     BRASERO_BURN_ERROR,
+			     BRASERO_BURN_ERROR_DISK_SPACE,
+			     _("The location you chose to store the temporary image on does not have enough free space for the disc image (%ld MiB needed)"),
+			     (unsigned long) output_size / 1048576);
+		return BRASERO_BURN_ERR;
+	}
+
+	/* Last but not least, use getrlimit () to check that we are allowed to
+	 * write a file of such length and that quotas won't get in our way */
+	if (getrlimit (RLIMIT_FSIZE, &limit)) {
+		g_set_error (error,
+			     BRASERO_BURN_ERROR,
+			     BRASERO_BURN_ERROR_DISK_SPACE,
+			     strerror (errno));
+		return BRASERO_BURN_ERR;
+	}
+
+	if (limit.rlim_cur < output_size) {
+		BRASERO_BURN_LOG ("User not allowed to write such a large file");
+
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_DISK_SPACE,
@@ -520,7 +563,7 @@ brasero_job_set_output_file (BraseroJob *self,
 
 		BRASERO_JOB_LOG (self, "output set (IMAGE) image = %s toc = %s",
 				 image,
-				 toc);
+		    toc ? toc : "nil");
 	}
 	else if (priv->type.type == BRASERO_TRACK_TYPE_AUDIO) {
 		/* NOTE: this one can only a temporary file */
@@ -617,8 +660,7 @@ brasero_job_item_start (BraseroTaskItem *item,
 		}
 	}
 	else
-		BRASERO_JOB_LOG (self, "linked to %s",
-				 G_OBJECT_TYPE_NAME (priv->linked));
+		BRASERO_JOB_LOG (self, "linked to %s", G_OBJECT_TYPE_NAME (priv->linked));
 
 	if (!brasero_job_is_first_active (self)) {
 		int fd [2];
@@ -1517,6 +1559,7 @@ brasero_job_get_max_speed (BraseroJob *self, guint *speed)
 	session = brasero_task_ctx_get_session (priv->ctx);
 
 	drive = brasero_burn_session_get_burner (session);
+	medium = brasero_drive_get_medium (drive);
 	rate = brasero_medium_get_max_write_speed (medium);
 	media = brasero_medium_get_status (medium);
 	if (media & (BRASERO_MEDIUM_DVD|BRASERO_MEDIUM_DVD_DL))
@@ -1657,14 +1700,15 @@ brasero_job_set_progress (BraseroJob *self,
 {
 	BraseroJobPrivate *priv;
 
-	BRASERO_JOB_DEBUG (self);
-
+	BRASERO_JOB_LOG (self, "Called brasero_job_set_progress (%lf)", progress);
 	priv = BRASERO_JOB_PRIVATE (self);
 	if (priv->next)
 		return BRASERO_BURN_ERR;
 
-	if (progress < 0.0 || progress > 1.0)
+	if (progress < 0.0 || progress > 1.0) {
+		BRASERO_JOB_LOG (self, "Tried to set an insane progress value (%lf)", progress);
 		return BRASERO_BURN_ERR;
+	}
 
 	return brasero_task_ctx_set_progress (priv->ctx, progress);
 }
@@ -1804,7 +1848,8 @@ brasero_job_set_dangerous (BraseroJob *self, gboolean value)
 	BRASERO_JOB_DEBUG (self);
 
 	priv = BRASERO_JOB_PRIVATE (self);
-	brasero_task_ctx_set_dangerous (priv->ctx, value);
+	if (priv->ctx)
+		brasero_task_ctx_set_dangerous (priv->ctx, value);
 }
 
 /**
